@@ -1,12 +1,15 @@
 from shutil import rmtree
+from typing import Any, cast
 
 from pyarr import SonarrAPI
 
 from .download import Download
 
+json = dict[str, Any]
+
 
 class Series:
-    def __init__(self, series_json: dict) -> None:
+    def __init__(self, series_json: dict[str, Any]) -> None:
         self.title: str = series_json["title"]
         self.year: int = series_json["year"]
         self.tvdb_id: int = series_json["tvdbId"]
@@ -41,7 +44,9 @@ class Sonarr:
         self._sonarr = SonarrAPI(url, api_key)
 
     def lookup_series(self, query: str) -> list[Series]:
-        possible_series = self._sonarr.lookup_series(query)
+        possible_series = cast(
+            list[json] | dict[str, Any], self._sonarr.lookup_series(query)
+        )
 
         if isinstance(possible_series, dict):
             raise SonarrError(possible_series["message"])
@@ -49,23 +54,40 @@ class Sonarr:
         return [Series(s) for s in possible_series]
 
     def lookup_library(self, query: str) -> list[Series]:
-        possible_series = self._sonarr.lookup_series(query)
+        possible_series = cast(list[json], self._sonarr.lookup_series(query))
 
         return [Series(s) for s in possible_series if "id" in s]
 
+    def lookup_user_library(self, query: str, user_id: int) -> list[Series]:
+        try:
+            tag_id = self._get_tag_for_user_id(user_id)
+        except ValueError:
+            return []
+
+        possible_series = cast(list[json], self._sonarr.lookup_series(query))
+
+        # self._sonarr.get_tag_detail is broken/not supported in v1 sonarr API so have
+        # to filter the tmdb lookup (probably slower but saves an API call)
+        user_series = [s for s in possible_series if tag_id in s["tags"]]
+
+        return [Series(s) for s in user_series]
+
     def add_series(self, series: Series, profile: str = "good") -> bool:
         if series.db_id is not None:
             return False
 
         quality_profile_id = self._get_quality_profile_id(profile)
 
-        root_folder = self._sonarr.get_root_folder()[0]["path"]
+        root_folder = cast(list[json], self._sonarr.get_root_folder())[0]["path"]
 
-        series_json = self._sonarr.add_series(
-            tvdb_id=series.tvdb_id,
-            quality_profile_id=quality_profile_id,
-            root_dir=root_folder,
-            search_for_missing_episodes=True,
+        series_json = cast(
+            json,
+            self._sonarr.add_series(
+                tvdb_id=series.tvdb_id,
+                quality_profile_id=quality_profile_id,
+                root_dir=root_folder,
+                search_for_missing_episodes=True,
+            ),
         )
 
         series.db_id = series_json["id"]
@@ -76,7 +98,7 @@ class Sonarr:
         if series.db_id is None:
             raise ValueError(f"{series} is not in the library")
 
-        series_json = self._sonarr.get_series(series.db_id)
+        series_json = cast(json, self._sonarr.get_series(series.db_id))
 
         self._sonarr.del_series(series.db_id, delete_files=True)
 
@@ -107,7 +129,7 @@ class Sonarr:
 
             return False
 
-        series_json = self._sonarr.get_series(series.db_id)
+        series_json = cast(json, self._sonarr.get_series(series.db_id))
 
         series_json["tags"].append(tag_id)
 
@@ -116,7 +138,7 @@ class Sonarr:
         return True
 
     def get_downloads(self) -> list[Download]:
-        queue = self._sonarr.get_queue()
+        queue = cast(list[json], self._sonarr.get_queue())
 
         downloads = [Download(d) for d in queue]
 
@@ -130,7 +152,7 @@ class Sonarr:
 
         total = 0
 
-        for series in self._sonarr.get_series():
+        for series in cast(list[json], self._sonarr.get_series()):
             if tag_id in series["tags"]:
                 try:
                     total += series["sizeOnDisk"]
@@ -139,12 +161,12 @@ class Sonarr:
 
         return total
 
-    def get_quality_profile_name(self, profile_id: int):
-        profiles = self._sonarr.get_quality_profile()
+    def get_quality_profile_name(self, profile_id: int) -> str:
+        profiles = cast(list[json], self._sonarr.get_quality_profile())
 
         for profile in profiles:
             if profile["id"] == profile_id:
-                return profile["name"]
+                return cast(str, profile["name"])
 
         raise ValueError(f"no quality profile with the id {profile_id}")
 
@@ -152,19 +174,19 @@ class Sonarr:
         self._sonarr.post_command("RescanSeries", seriesId=series_id)
 
     def _get_quality_profile_id(self, name: str) -> int:
-        profiles = self._sonarr.get_quality_profile()
+        profiles = cast(list[json], self._sonarr.get_quality_profile())
 
         for profile in profiles:
             if profile["name"].lower() == name.lower():
-                return profile["id"]
+                return cast(int, profile["id"])
 
         raise ValueError(f"no quality profile with the name {name}")
 
     def _get_tag_for_user_id(self, user_id: int) -> int:
-        tags = self._sonarr.get_tag()
+        tags = cast(list[json], self._sonarr.get_tag())
 
         for tag in tags:
             if str(user_id) in tag["label"]:
-                return tag["id"]
+                return cast(int, tag["id"])
 
         raise ValueError(f"no tag with the user id {user_id}")
