@@ -1,6 +1,7 @@
 import asyncio
 import logging
 import traceback
+from typing import Any
 
 import discord
 from discord.ext import commands
@@ -20,12 +21,14 @@ sonarr = Sonarr(config["sonarr"]["url"], config["sonarr"]["api_key"])
 
 
 @bot.check
-async def check_channel(ctx: commands.Context) -> bool:
+async def check_channel(ctx: commands.Context[Any]) -> bool:
     return ctx.channel.id == config["discord"]["channel_id"]
 
 
 @bot.event
-async def on_command_error(ctx: commands.Context, error: commands.CommandError) -> None:
+async def on_command_error(
+    ctx: commands.Context[Any], error: commands.CommandError
+) -> None:
     match error:
         case commands.CommandNotFound() | commands.CheckFailure():
             pass
@@ -64,7 +67,7 @@ async def on_ready() -> None:
 
 
 @bot.before_invoke
-async def before_invoke(ctx: commands.Context) -> None:
+async def before_invoke(ctx: commands.Context[Any]) -> None:
     logger.debug(f"got command from {ctx.message.author}: {ctx.message.content}")
 
 
@@ -72,7 +75,7 @@ async def before_invoke(ctx: commands.Context) -> None:
 @bot.command(
     name="downloads", aliases=["queue", "q"], help="see the status of movie downloads"
 )
-async def downloads_cmd(ctx: commands.Context) -> None:
+async def downloads_cmd(ctx: commands.Context[Any]) -> None:
     async with ctx.typing():
         queue = radarr.get_downloads() + sonarr.get_downloads()
 
@@ -87,7 +90,7 @@ async def downloads_cmd(ctx: commands.Context) -> None:
 
 @commands.cooldown(1, 60, commands.BucketType.user)  # type: ignore
 @bot.command(name="quota", help="see your used space on the plex")
-async def quota_cmd(ctx: commands.Context) -> None:
+async def quota_cmd(ctx: commands.Context[Any]) -> None:
     async with ctx.typing():
         used = (
             radarr.get_quota_amount(ctx.message.author.id)
@@ -113,7 +116,7 @@ async def quota_cmd(ctx: commands.Context) -> None:
 
 @commands.cooldown(1, 60)  # type: ignore
 @bot.command(name="quotas", help="see everyone's used space on the plex")
-async def quotas_cmd(ctx: commands.Context) -> None:
+async def quotas_cmd(ctx: commands.Context[Any]) -> None:
     try:
         quotas = config["discord"]["quotas"]
     except ValueError:
@@ -146,7 +149,9 @@ async def quotas_cmd(ctx: commands.Context) -> None:
 
 @bot.command(name="addtag", help="add a user tag")  # type: ignore
 @commands.has_role("plex-admin")
-async def addtag_cmd(ctx: commands.Context, name: str, user: discord.Member) -> None:
+async def addtag_cmd(
+    ctx: commands.Context[Any], name: str, user: discord.Member
+) -> None:
     tag = f"{name}: {user.id}"
 
     radarr.create_tag(tag)
